==> nextcloud-26.0.9.tgz: nextcloud/apps/comments/l10n/ca.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentaris",
    "You commented" : "Heu escrit un comentari",
    "{author} commented" : "{author} ha escrit un comentari",
    "You commented on %1$s" : "Heu escrit un comentari a %1$s",
    "You commented on {file}" : "Heu escrit un comentari a {file}",
    "%1$s commented on %2$s" : "%1$s ha escrit un comentari a %2$s",
    "{author} commented on {file}" : "{author} ha escrit un comentari a {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentaris</strong> per a fitxers",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Se us ha esmentat a «{file}» en un comentari d'un usuari que s'ha suprimit",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} us ha esmentat en un comentari a «{file}»",
    "Files app plugin to add comments to files" : "Connector de l'aplicació Fitxers per a afegir comentaris als fitxers",
    "Edit comment" : "Edita el comentari",
    "Delete comment" : "Suprimeix el comentari",
    "Cancel edit" : "Cancel·la l'edició",
    "Post comment" : "Publica el comentari",
    "Could not reload comments" : "No s'han pogut tornar a carregar els comentaris",
    "No comments yet, start the conversation!" : "Encara no hi ha cap comentari. Enceteu la conversa!",
    "No more messages" : "No hi ha més missatges",
    "Retry" : "Torna-ho a provar",
    "Failed to mark comments as read" : "No s'han pogut marcar els comentaris com a llegits",
    "Unable to load the comments list" : "No s'ha pogut carregar la llista de comentaris",
    "_1 new comment_::_{unread} new comments_" : ["1 comentari nou","{unread} comentaris nous"],
    "Comment" : "Comentari",
    "An error occurred while trying to edit the comment" : "S'ha produït un error en intentar editar el comentari",
    "Comment deleted" : "S'ha suprimit el comentari",
    "An error occurred while trying to delete the comment" : "S'ha produït un error en intentar suprimir el comentari",
    "An error occurred while trying to create the comment" : "S'ha produït un error en intentar crear el comentari",
    "%1$s commented" : "%1$s ha escrit un comentari",
    "_%n unread comment_::_%n unread comments_" : ["%n comentari sense llegir","%n comentaris sense llegir"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/comments/l10n/ca.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentaris",
    "You commented" : "Heu escrit un comentari",
    "{author} commented" : "{author} ha escrit un comentari",
    "You commented on %1$s" : "Heu escrit un comentari a %1$s",
    "You commented on {file}" : "Heu escrit un comentari a {file}",
    "%1$s commented on %2$s" : "%1$s ha escrit un comentari a %2$s",
    "{author} commented on {file}" : "{author} ha escrit un comentari a {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentaris</strong> per a fitxers",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Se us ha esmentat a «{file}» en un comentari d'un usuari que s'ha suprimit",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} us ha esmentat en un comentari a «{file}»",
    "Files app plugin to add comments to files" : "Connector de l'aplicació Fitxers per a afegir comentaris als fitxers",
    "Edit comment" : "Edita el comentari",
    "Delete comment" : "Suprimeix el comentari",
    "Cancel edit" : "Cancel·la l'edició",
    "Post comment" : "Publica el comentari",
    "@ for mentions, : for emoji, / for smart picker" : "@ per a mencions, : per a emojis, / per al selector intel·ligent",
    "Could not reload comments" : "No s'han pogut tornar a carregar els comentaris",
    "No comments yet, start the conversation!" : "Encara no hi ha cap comentari. Enceteu la conversa!",
    "No more messages" : "No hi ha més missatges",
    "Retry" : "Torna-ho a provar",
    "Failed to mark comments as read" : "No s'han pogut marcar els comentaris com a llegits",
    "Unable to load the comments list" : "No s'ha pogut carregar la llista de comentaris",
    "_1 new comment_::_{unread} new comments_" : ["1 comentari nou","{unread} comentaris nous"],
    "Comment" : "Comentari",
    "An error occurred while trying to edit the comment" : "S'ha produït un error en intentar editar el comentari",
    "Comment deleted" : "S'ha suprimit el comentari",
    "An error occurred while trying to delete the comment" : "S'ha produït un error en intentar suprimir el comentari",
    "An error occurred while trying to create the comment" : "S'ha produït un error en intentar crear el comentari",
    "_%n unread comment_::_%n unread comments_" : ["%n comentari sense llegir","%n comentaris sense llegir"]
},
"nplurals=2; plural=(n != 1);");
